*****************************************************************************************************************
*  Foreign Aid Allocation Tactics and Democratic Change in Africa
*  Joseph Wright
*  Simone Dietrich
*  
*  Origin date:  2.26.14 jgw
*  Last updated: 5.5.14 jgw
*
*  Using .do files:
* 	AidGraph.do
* 	CleanData.do
*	CleanOECDTrade.do
* 	cowcodes.do
*	Exogeneity.do
*	Placebo.do
*
*  Using .ado files:
*	uci.ado
*	
*  Using .dta files:
*	africa_data2.dta
*	AidDatav192.dta
*	AidDatav192_USprojects.dta
*	alliance_oecd.dta
*	cg_original.dta
*	ef.dta
*	IMFprogram.dta
*	IMFtrade.dta                /* used to create trade.dta */
*	IncumbentVote.dta
*	ingos.dta
*	instrument_merge.dta        /* created from inst_weight_dist.do */
*	neldav3_new.dta
*	rawmp.dta
*	RossOil2009.dta
* 	stockforeign_oecd.dta
*
*  Using files in distance folder:
*	aiddat_dyadic-merge.dta
*	distance.dta
*	wdidonors.dta
*	WomenParl.dta
*	inst_weight_dist.do
*
*  Using Stata 12.1
*
****************************************************************************************************

clear
cd "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Replication data files"

capture log close
log using "DietrichWrightJOPFinal.log", replace

set more off
set scheme lean1

do CleanData        	/* This file merges data sets, call another file to create the outside instruments, and contains internal programs for creating the sample data set for Tables 1 & 2, 3, and 4 */
do Placebo			/* This file creates the graphs for the bottom panel of Figure 1 */
do AidGraph           	/* This file creates the graphs for top panel of Figure 1 and for Figure 2 */
do Exogeneity          	/* This file implements the UCI tests; and examines whether there is a homogenous treatment effect */

*************************
*NGO's and democracy aid*
*************************
qui prep1 
tsset cow year
gen laid =ln(1+a2_pc)
gen alligo = ln((exp(ngo)-1) + (exp(igo)-1) + 1)
global c = "lgdp lpop cwar dnmp* dmp*"

*igo and ngo are highly correlated*
corr igo ngo laid if lmp~=.

xi: qui reg laid igo if lmp!=., cluster(cow)
lincom igo
est store igo1
xi: qui reg laid ngo if lmp!=., cluster(cow)
lincom ngo
est store igo2
xi: qui reg laid alligo if lmp!=., cluster(cow)
lincom alligo
est store igo3
xi: qui reg laid igo $c if lmp!=., cluster(cow)
lincom igo
est store igo4
xi: qui reg laid ngo $c if lmp!=., cluster(cow)
lincom ngo
est store igo5
xi: qui reg laid alligo $c if lmp!=., cluster(cow)
lincom alligo
est store igo6
xi: qui reg laid l.laid $c igo if lmp!=., cluster(cow)
lincom igo
est store igo7
xi: qui reg laid l.laid $c ngo if lmp!=., cluster(cow)
lincom ngo
est store igo8
xi: qui reg laid l.laid $c alligo if lmp!=., cluster(cow)
lincom alligo
est store igo9
xi: qui reg laid  yr* $c igo i.cow if lmp!=., cluster(cow)  
lincom igo
est store igo10
xi: qui reg laid yr* $c ngo i.cow if lmp!=., cluster(cow)
lincom ngo
est store igo11
xi: qui reg laid  yr* $c alligo i.cow if lmp!=., cluster(cow)  
lincom alligo
est store igo12
estout igo* using IGODemaid.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(ll r2 N) style(tex) replace label starlevels(* 0.10 ** 0.05)

***********************************************************************************
**Alternative Channels are generally not correlated with the excluded instruments**
***********************************************************************************
qui prep1
rename stock migrants
rename ally alliance
rename io3count IOmembership
rename igo NGOintl
rename ngo NGOdomestic
set scheme s1mono
corrtex Iinfl3 Iwip3 trade NGOintl NGOdomestic migrants alliance IOmembership if lmp~=. ,file(AltChannel) replace   title(Correlations)
local policy = "trade NGOintl NGOdomestic migrants alliance IOmembership"
foreach x of local policy {
	qui reg Iinfl3 lpop lgdp cwar dnmp* dmp* if lmp!=.  , cluster(cow)
	avplot `x', title("`x'")  saving(`x') ytitle("") xtitle("")
}
gr combine NGOintl.gph NGOdomestic.gph trade.gph migrants.gph alliance.gph IOmembership.gph, col(2)   ysize(15) xsize(18)
graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\AltInfl.pdf", as(pdf)  replace
local policy = "trade NGOintl NGOdomestic migrants alliance IOmembership"
foreach z of local policy { 
	erase `z'.gph
}
local policy = "trade NGOintl NGOdomestic migrants alliance IOmembership"
foreach x of local policy {
	qui reg Iwip3 lpop lgdp cwar dnmp* dmp*  if lmp~=.   , cluster(cow) 
	avplot `x', title("`x'")  saving(`x') ytitle("") xtitle("")
}
gr combine NGOintl.gph NGOdomestic.gph trade.gph migrants.gph alliance.gph IOmembership.gph, col(2)   ysize(15) xsize(18)
graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\AltWip.pdf", as(pdf) replace
local policy = "trade NGOintl NGOdomestic migrants alliance IOmembership"
foreach z of local policy { 
	erase `z'.gph
}


***Lewbel instrument program***          /* this "program" demonstrates how the lewbel instrument is created "by hand" to compare estimates with canned program; the equation itself is meaningless */
qui prep1
qui reg econaid lgdp  if lmp==0    /* Excluded outside instrument goes into the `auxillary' first stage */
qui predict res  if e(sample), res
qui egen mean=mean(lgdp) if e(sample)
qui gen inst_lgdp = (lgdp-mean)*res
ivreg2 mp (econaid= inst_lgdp ) lgdp if lmp==0, first
ivreg2h mp (econaid= ) lgdp if lmp==0, first
drop mean res inst_lgdp

*****************************************************************************
** Testing for presence of heteroskedasticity in the first-stage equations **   
*****************************************************************************
/* Remember that the Lewbel approach only enhances efficiency of the two-stage estimator IF there is heteroskedasticity present in the "first-stage" equation */
qui prep1
global c = "lgdp lpop cwar dnmp*"
qui reg econaid Iinfl3 $c if lmp==0
estat hettest
qui reg demaid Iwip3 $c if lmp==0
estat hettest
global c = "lgdp lpop cwar dmp*"
qui reg econaid Iinfl3 $c if lmp==1
estat hettest
ivreg2 mp (econaid = Iinfl3) $c if lmp==1, cluster(cow) ffirst
est store c1
qui reg demaid Iwip3 $c if lmp==1
estat hettest  

qui prep2
global c = "lgdp lpop IMF3 first monitor"
qui reg econaid $c Iinfl3  
estat hettest
qui reg demaid $c Iwip3  
estat hettest
ivreg2 harass (demaid = Iwip3) $c, cluster(cow) ffirst
est store c2		
		
qui prep3
global c = "lgdp lpop gr IMF3"
qui reg econaid $c Iinfl3  
estat hettest
ivreg2 shareopp (econaid = Iinfl3  ) $c, cluster(cow) ffirst
est store c3
ivreg2 shareopp (econaid = Iinfl3  ) $c if incshare<.9, cluster(cow) ffirst
est store c4
qui reg demaid $c Iwip3  
estat hettest	
ivreg2 shareopp (demaid = Iwip3  ) $c, cluster(cow) ffirst
est store c5
ivreg2 shareopp (demaid = Iwip3  ) $c if incshare<.9, cluster(cow) ffirst
est store c6

estout c* using AppendixC2.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(ll r2 N) style(tex) replace label starlevels(* 0.10 ** 0.05)

*These tests are reported in Appendix C*

********************************************************
** Show outside instrument correlation with aid types **
********************************************************
qui prep1	
rename Iinfl3  Inflation 
rename   Iwip3 WiP 	
global c = "lgdp lpop cwar dnmp* dmp*"
qui reg econaid $c Inflation if lmp~=.
avplot Inflation
graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\EconInfl.pdf", as(pdf)  replace
qui reg econaid $c WiP if lmp~=.
avplot WiP	
graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\EconWip.pdf", as(pdf)  replace
qui reg demaid $c Inflation if lmp~=.
avplot Inflation
graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\DemInfl.pdf", as(pdf)  replace
qui reg demaid $c WiP if lmp~=.
avplot WiP		
graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\DemWip.pdf", as(pdf)  replace

***************************
** Mulitparty Transition **              
***************************
/* These models are reported in Table 1 in the main text */
qui prep1  
global c = "lgdp lpop cwar dnmp*"
 
*Reported models
reg mp econaid $c if lmp==0, cluster(cow)
est store tr1
lincom econaid*(1.03662*2)
ivreg2h mp (econaid =Iinfl3) $c if lmp==0, cluster(cow) first gen
ivreg2 mp (econaid =Iinfl3 econaid_*) $c if lmp==0, cluster(cow) orthog(Iinfl3)
est store tr2
lincom econaid*(1.03662*2)
sutex mp econaid demaid $c Iinfl3 Iwip3 if e(sample), minmax labels file(sumstatTable1.tex) replace   digits(1)
qui reg econaid Iinfl3 $c econaid_*, cluster(cow)
test Iinfl3
test econaid_lgdp_g econaid_lpop_g econaid_cwar_g econaid_dnmp_g econaid_dnmp2_g econaid_dnmp3_g
ivprobit mp (econaid = Iinfl3 econaid_*) $c if lmp==0, cluster(cow)
est store tr3
lincom econaid*(1.03662*2)
reg mp demaid $c if lmp==0, cluster(cow)
est store tr4
lincom demaid*(.6747269*2)
ivreg2h mp (demaid =Iwip3) $c if lmp==0, cluster(cow)  first gen  
ivreg2 mp (demaid =Iwip3 demaid_*) $c if lmp==0, cluster(cow)  first   
est store tr5
lincom demaid*(.6747269*2)
qui reg demaid Iwip3 $c demaid_*, cluster(cow)
test Iwip3
test demaid_lgdp_g demaid_lpop_g demaid_cwar_g demaid_dnmp_g demaid_dnmp2_g demaid_dnmp3_g
ivprobit mp (demaid =Iwip3 demaid_*) $c if lmp==0, cluster(cow)
est store tr6
lincom demaid*(.6747269*2)

*Without South Africa*
ivreg2 mp (econaid =Iinfl3  ) $c if lmp==0 & cow~=560, cluster(cow)  ffirst
ivreg2h mp (econaid =Iinfl3  ) $c if lmp==0 & cow~=560, cluster(cow)  ffirst

*All Lewbel instruments, without INFL as an instrument
ivreg2 mp (econaid = econaid_*) $c if lmp==0, cluster(cow)       
est store b1m1

*Just duration Lewbel instruments, with INFL as an instrument*
ivreg2 mp (econaid = Iinfl3 econaid_dnmp_g econaid_dnmp2_g econaid_dnmp3_g) $c if lmp==0, cluster(cow) orthog(Iinfl3)
est store b1m2

*IV with 2-way FE*
tsset cow year
xi: xtivreg2  mp (econaid = Iinfl3 econaid_*) $c yr* if lmp==0, cluster(cow) fe ffirst
est store b1m3

*Exclude island countries*
xi: ivreg2  mp (econaid = Iinfl3 econaid_*) $c if lmp==0 & small==0 , cluster(cow)   orthog(Iinfl3)  
est store b1m4

*No controls except duration*
ivreg2 mp (econaid =Iinfl3 econaid_dnmp_g econaid_dnmp2_g econaid_dnmp3_g) dnmp* if lmp==0, cluster(cow)  orthog(Iinfl3)
est store b1m5

*Add controls: trade, igos, un mission troops, alliance*
local policy = "ef_preg oil IMF3 gr trade igo ngo stock io3count ally"
local z = 6
foreach x of local policy {
	qui ivreg2 mp (econaid =Iinfl3 econaid_*) `x' $c   if lmp==0, cluster(cow)   orthog(Iinfl3) 
	lincom econaid*(1.03662*2)
	est store b1m`z'
	local z = `z' +1
}

estout tr1 tr2 tr3 tr4 tr5 tr6 using MPtrans.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)
estout b1m* using AppendixB1.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)

		** truncate sample to show that Econ Aid estimates are similiar in OLS and IV **
		qui prep1  
		global c = "lgdp lpop cwar dnmp*"
		local t = 1992
		
		xi: qui reg mp econaid $c   if lmp==0 & year>`t', cluster(cow)
		lincom econaid 
		est store bx1
		xi: qui ivreg2h mp (econaid =Iinfl3)   $c if lmp==0  & year>`t', cluster(cow) gen
		lincom econaid 
		est store bx2

		xi: qui probit mp econaid $c   if lmp==0  & year>`t', cluster(cow)
		lincom econaid
		est store bx3
		xi: qui ivprobit mp (econaid =Iinfl3 econaid_*)   $c if lmp==0  & year>`t', cluster(cow)
		lincom econaid 
		est store bx4


********************
*Multiparty failure*
********************
/* These models are reported in Table 2 in the main text */
qui prep1
global c = "lgdp lpop cwar dmp*"
 
*Reported models
reg mp econaid $c if lmp==1, cluster(casename)
est store fa1
lincom econaid*(0.80*2)
qui ivreg2h mp (econaid =Iinfl3) $c if lmp==1, cluster(casename) first gen
ivreg2 mp (econaid =Iinfl3 econaid_*) $c if lmp==1, cluster(casename) orthog(Iinfl3) ffirst
est store fa2
lincom econaid*(0.80*2)
sutex mp econaid demaid $c Iinfl3 Iwip3 if e(sample), minmax labels file(sumstatTable2.tex) replace   digits(1)
reg econaid Iinfl3 $c econaid_*, cluster(casename)
test Iinfl3
test econaid_lgdp_g econaid_lpop_g econaid_cwar_g econaid_dmp_g econaid_dmp2_g econaid_dmp3_g
ivprobit mp (econaid = Iinfl3 econaid_*) $c if lmp==1, cluster(casename)
est store fa3
lincom econaid*(0.80*2)
reg mp demaid $c if lmp==1, cluster(casename)
est store fa4
lincom demaid*(.67*2)
qui ivreg2h mp (demaid =Iwip3) $c if lmp==1, cluster(casename)  first gen 
ivreg2 mp (demaid =Iwip3 demaid_*) $c if lmp==1, cluster(casename) ffirst  orthog(Iwip3)
est store fa5
lincom demaid*(.67*2)
reg demaid Iwip3 $c demaid_*, cluster(casename)
test Iwip3
test demaid_lgdp_g demaid_lpop_g demaid_cwar_g demaid_dmp_g demaid_dmp2_g demaid_dmp3_g
ivprobit mp (demaid =Iwip3 demaid_*) $c if lmp==1, cluster(casename)
est store fa6
lincom demaid*(.67*2)


*Just duration Lewbel instruments, with WIP as an instrument*
ivreg2 mp (demaid = Iwip3 demaid_dmp_g demaid_dmp2_g demaid_dmp3_g) $c if lmp==1, cluster(cow) orthog(Iwip3) ffirst
est store b2m1

*IV with 2-way FE*
tsset cow year
xi: xtivreg2  mp (demaid = Iwip3 demaid_*) $c  yr* if lmp==1, cluster(cow)  fe     ffirst
est store b2m2

*Exclude island countries*
xi: ivreg2  mp (demaid = Iwip3 demaid_*) $c if lmp==1 & small==0 , cluster(cow) ffirst   orthog(Iwip3) 
est store b2m3

*No controls except duration*
ivreg2h mp (demaid =Iwip3) dmp*  if lmp==1, cluster(cow) ffirst
est store b2m4

*Add controls: trade, igos, un mission troops, alliance*
local policy = "ef_preg oil IMF3 gr trade igo ngo stock io3count ally"
local z = 5
foreach x of local policy {
	qui ivreg2 mp (demaid =Iwip3 demaid_*) `x' $c   if lmp==1, cluster(casename) orthog(Iwip3)  ffirst
	lincom demaid
	est store b2m`z'
	local z = `z' +1
}

estout fa1 fa2 fa3 fa4 fa5 fa6 using MPfail.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)
estout b2m1 b2m2 b2m3 b2m4 b2m5 b2m6 b2m7 b2m8 b2m9 b2m10 b2m11 b2m12 b2m13 b2m14 using AppendixB2.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(+ 0.15 * 0.10 ** 0.05)

************************************
** FE LPM no IV for multipartyism **
************************************
qui prep1
tsset cow year
xi: qui xtreg mp econaid i.year cwar if lmp==0, cluster(cow) fe
lincom econaid
est store fe1
xi: qui xtreg mp econaid time time2 cwar   if lmp==0, cluster(cow) fe
lincom econaid
est store fe2
xi: qui  reg  mp econaid i.cow*time cwar  if lmp==0, cluster(cow)  
lincom econaid  
est store fe3
xi: qui xtreg mp demaid i.year cwar if lmp==1, cluster(cow) fe
lincom demaid
est store fe4
xi: qui xtreg mp demaid time  time2 cwar if lmp==1, cluster(cow) fe
lincom demaid
est store fe5
xi: qui  reg mp demaid i.cow*time cwar if lmp==1, cluster(cow)  
lincom demaid
est store fe6
set matsize 800
estout fe* using AppendixB3.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)

**********************
*Electoral Misconduct*
**********************
/* These models are reported in Table 3 in the main text */
prep2
global c = "lgdp lpop IMF3 first monitor"

reg harass $c econaid, cluster(cow)
est store ha1
qui ivreg2h  harass $c (econaid = Iinfl3   ),  first  gen cluster(cow)
ivreg2  harass $c (econaid = Iinfl3 econaid_*  ),  ffirst cluster(cow) orthog(Iinfl3)
sutex harass econaid demaid $c Iinfl3 Iwip3 if e(sample), minmax labels file(sumstatTable3.tex) replace   digits(1)
est store ha2
qui reg econaid $c Iinfl3 econaid_* if e(sample), cluster(cow)
test Iinfl3
test econaid_lgdp_g econaid_lpop_g econaid_IMF3_g econaid_first_g econaid_monitor_g
ivprobit harass $c (econaid =  Iinfl3 econaid_* ), cluster(cow)
est store ha3
 
reg harass $c demaid , cluster(cow)
est store ha4
qui ivreg2h  harass $c (demaid = Iwip3),  first  gen  cluster(cow)  
ivreg2  harass $c (demaid =  Iwip3 demaid_*),  ffirst  cluster(cow) orthog(Iwip3) 
est store ha5
qui reg demaid $c Iwip3 demaid_* if e(sample), cluster(cow)
test Iwip3
test demaid_lgdp_g demaid_lpop_g demaid_IMF3_g demaid_first_g demaid_monitor_g
ivreg2 harass $c (demaid = Iwip3),  first  cluster(cow)  
ivprobit harass $c (demaid = Iwip3 demaid_*), cluster(cow)
est store ha6

*Dem aid robust to extra controls*  
local policy = "expect boycott civilwar3 gr ef_preg trade igo ngo io3count stock ally"
local z = 1
foreach x of local policy {
	qui ivreg2 harass $c (demaid =Iwip3  demaid_*) `x',cluster(cow)   orthog(Iwip3)
	lincom demaid
	est store b3m`z'
	qui ivprobit harass $c (demaid =Iwip3  demaid_*) `x',cluster(cow) 
	lincom demaid
	local z = `z' +1
}

 
*Drop island countries*
xi: ivreg2 harass $c (demaid =Iwip3  demaid_*) if small==0, cluster(cow)   ffirst orthog(Iwip3)
lincom demaid
est store b3m12
qui ivprobit harass_p $c (demaid =Iwip3  demaid_*) if small==0, cluster(cow) 
lincom demaid

* Drop civil war years*
xi: ivreg2 harass $c  (demaid =Iwip3 demaid_*) if prio_lconflict_intra==0, cluster(cow)   ffirst orthog(Iwip3)
lincom demaid
est store b3m13
qui ivprobit harass $c (demaid =Iwip3 demaid_*) if prio_lconflict_intra==0, cluster(cow) 
lincom demaid

* Pres *
xi: ivreg2h harass_p $c  (demaid = Iwip3 ) if prio_lconflict_intra==0, cluster(cow)   ffirst  
lincom demaid
  
* Leg *
xi: ivreg2h harass_l $c  (demaid = Iwip3 ) if prio_lconflict_intra==0, cluster(cow)   ffirst  
lincom demaid
  

estout ha1 ha2 ha3 ha4 ha5 ha6 using Harass.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)
estout b3m* using AppendixB4.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)
 

*****************
*Opposition Vote*
*****************
/* These models are reported in Table 4 in the main text */
prep3
global c = "lgdp lpop gr IMF3"

*Reported models: opposition share of two-party vote*
reg shareopp econaid $c, cluster(cow)
	nlcom (invlogit(_b[econaid]*.75))-.5 
	est store op1
qui ivreg2h shareopp (econaid = Iinfl3  ) $c, cluster(cow) first  gen
ivreg2 shareopp (econaid = Iinfl3 econaid_* ) $c, cluster(cow) ffirst orthog(Iinfl3)
	nlcom (invlogit(_b[econaid]*.75))-.5 
	est store op2
    qui reg econaid Iinfl3 $c econaid_*, cluster(cow)
	test Iinfl3
	test econaid_lgdp_g econaid_lpop_g econaid_gr_g econaid_IMF3_g
	est store oppfirst1
	drop econaid_*
sutex shareopp econaid demaid $c Iinfl3 Iwip3 if e(sample), minmax labels file(sumstatTable4.tex) replace   digits(1)
ivreg2h shareopp (econaid = Iinfl3  ) $c if incshare<.9, cluster(cow)  first gen
	nlcom (invlogit(_b[econaid]*.75))-.5 
	est store op3
    qui reg econaid Iinfl3 $c econaid_* if incshare<.9, cluster(cow)
	test Iinfl3
	test econaid_lgdp_g econaid_lpop_g econaid_gr_g econaid_IMF3_g
	est store oppfirst2
	drop econaid_*
	
reg shareopp demaid $c, cluster(cow)
	nlcom (invlogit(_b[demaid]*.75))-.5 
	est store op4
qui ivreg2h shareopp (demaid = Iwip3 ) $c, cluster(cow) first  gen 
ivreg2 shareopp (demaid = Iwip3 demaid_*) $c, cluster(cow) ffirst  orthog(Iwip3) 
	nlcom (invlogit(_b[demaid]*.75))-.5 
	est store op5
	qui reg demaid Iwip3 $c demaid_*, cluster(cow)
	test Iwip3
	test demaid_lgdp_g demaid_lpop_g demaid_gr_g demaid_IMF3_g
	est store oppfirst3
	drop demaid_*
ivreg2h shareopp (demaid = Iwip3) $c if incshare<.9, cluster(cow)  gen
	nlcom (invlogit(_b[demaid]*.75))-.5 
	est store op6
	qui reg demaid Iwip3 $c demaid_* if incshare<.9, cluster(cow)
	test Iwip3
	test demaid_lgdp_g demaid_lpop_g demaid_gr_g demaid_IMF3_g
	est store oppfirst4
	drop demaid_*

*All opposition share of total vote*
ivreg2h voteopp (econaid = Iinfl3) $c, cluster(cow)   ffirst  
	nlcom (invlogit(_b[econaid]*.75))-.5 
	est store b5m1
ivreg2h voteopp (demaid = Iwip3) $c, cluster(cow)   ffirst  
	nlcom (invlogit(_b[demaid]*.75))-.5 
	est store b5m2
ivreg2h voteopp (econaid = Iinfl3) $c if incshare<.9, cluster(cow)   ffirst  
	nlcom (invlogit(_b[econaid]*.75))-.5 
	est store b5m3
ivreg2h voteopp (demaid = Iwip3) $c if incshare<.9, cluster(cow)   ffirst  
	nlcom (invlogit(_b[demaid]*.75))-.5 
	est store b5m4
	
*Lag DV models *
sort cow year
gen lvoteopp = voteopp[_n-1] if cow==cow[_n-1]
sort cow year
gen lshareopp = shareopp[_n-1] if cow==cow[_n-1]
ivreg2h shareopp lshareopp (econaid =Iinfl3) $c, cluster(cow)  ffirst  
	nlcom (invlogit(_b[econaid]*.75))-.5 
	est store b6m1
ivreg2h shareopp lshareopp (demaid =Iwip3) $c, cluster(cow)   ffirst  
	nlcom (invlogit(_b[demaid]*.75))-.5 
	est store b6m2
ivreg2h shareopp lshareopp (demaid =Iwip3) $c if incshare<.9, cluster(cow)   ffirst  
	nlcom (invlogit(_b[demaid]*.75))-.5 
	est store b6m3
ivreg2h voteopp lvoteopp (econaid =Iinfl3) $c, cluster(cow)  ffirst  
	nlcom (invlogit(_b[econaid]*.75))-.5 
	est store b6m4
ivreg2h voteopp lvoteopp (demaid =Iwip3) $c, cluster(cow)   ffirst  
	nlcom (invlogit(_b[demaid]*.75))-.5 
	est store b6m5
ivreg2h voteopp lvoteopp (demaid =Iwip3) $c if incshare<.9, cluster(cow)   ffirst  
	nlcom (invlogit(_b[demaid]*.75))-.5 
	est store b6m6

*Additional control variables*  Can't test ally because no variation in ally in sample
local policy = "civilwar oharass prevent trade igo ngo io3count stock"
local z =1
foreach x of local policy {
	qui ivreg2 shareopp (demaid = Iwip3) $c `x', cluster(cow)   ffirst 
	est store b7m`z'
	local z= `z' +1
	nlcom (invlogit(_b[demaid]*.75))-.5 
	qui ivreg2 shareopp (demaid = Iwip3) $c `x' if incshare<.9, cluster(cow)    ffirst  
	nlcom (invlogit(_b[demaid]*.75))-.5 
	est store b7m`z'
	local z= `z' +1
}

estout op1 op2 op3 op4 op5 op6 using OppVote.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)
estout b5m1 b5m2 b5m3 b5m4 using AppendixB5.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)
estout b6m1 b6m2 b6m3 b6m4 b6m5 b6m6 using AppendixB6.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)
estout b7m* using UnreportedVoteShare.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)
estout oppfirst* using OppFirst.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(ll r2 N) style(tex) replace label starlevels(* 0.10 ** 0.05)
 

** Big win aid **
gen bigwin = incshare>=.9
tab bigwin
gen xdem  = exp(demaid)-1
table bigwin, c(mean xdem)


***********************************************************************************************8

************************
** Substantive Graphs **
************************

*Transition*   Top panel of Figure 3
	qui prep1
	global c = "lgdp lpop cwar dnmp*"
	qui ivreg2h mp (econaid =Iinfl3) $c if lmp==0, cluster(cow) first gen
	sum $c if e(sample)
	pctile pct = econaid if e(sample), nq(20) genp(percent) 
	list percent pct in 1/19, clean
	drop percent pct 
	ivprobit mp (econaid = Iinfl3 econaid_*) $c if lmp==0, cluster(cow)
	set seed 339487731
	drawnorm b1-b24, n(10000) means(e(b)) cov(e(V))   clear
	gen a  =.
	gen hi =.
	gen lo =.
	gen med=.
	gen a_axis = (_n-1) in 1/81
	replace a_axis = a_axis/20 + 2 /*0.05 (log) aid increments from 2 to 5*/
	local a=2
	while `a' <= 5 {
		scalar h_gdp=6.851678   		/*mean*/
		scalar h_pop=8.571525  			/*mean*/
		scalar h_d = 25					/*mean*/
		scalar h_cw =.2243243			/*mean*/
		gen x_beta  = b1*`a'+b2*h_gdp+b3*h_pop+b4*h_cw+b5*h_d+b6*h_d^2+b7*h_d^3+b8*1
		gen prob = normal(x_beta)
		egen hatmed=mean(prob)
		_pctile prob, p(5,95)
		gen hatlo  = r(r1)
		gen hathi = r(r2)
		quietly replace a = `a' 
		quietly replace med = hatmed if a_axis==a
		quietly replace lo =  hatlo if a_axis==a
		quietly replace hi =  hathi if a_axis==a
		drop hat* x_beta prob
		local a = `a' + 0.05
	}
	local varname "lo hi med"
	foreach x of local varname {
		replace `x' = `x'*100
	}
	drop if a_axis>5
	merge using temp
	label var econaid "Economic Aid"
	graph twoway (hist econaid if econaid<=5 & econaid>=2, xscale(range(2 5)) xlabel(2 (0.5) 5) lcolor(gs12) bin(100) yaxis(2)) /*
	*/  (line hi a_axis, lpattern(dash) xscale(range(2 5)) xlabel(2 (0.5) 5) ytitle("Pr(Transition)") xtitle("Economic Aid (log scale)")) /*
	*/  (line lo a_axis, lpattern(dash) xscale(range(2 5)) xlabel(2 (0.5) 5) ytitle("Pr(Transition)") xtitle("Economic Aid (log scale)")) /*
	*/ (line med a_axis, lpattern(solid) legend(  order(4 "Estimate" 3 "90% CI" 1 "Aid distribution")    pos(12) col(3) ring(1)))
	* Aid = 3.3 is 25pctile: 5%; Aid = 4.3 is the 75pctile: 12%
	graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\Transition.pdf", as(pdf)  replace

*Failure*  Top panel of Figure 3
	qui prep1
	global c = "lgdp lpop cwar dmp dmp2"
	set seed 118974
	qui ivreg2h mp (demaid =Iwip3) $c if lmp==1, cluster(casename) first gen
	sum $c if e(sample)
	pctile pct = demaid if e(sample), nq(20) genp(percent) 
	list percent pct in 1/19, clean
	drop percent pct 
	ivprobit mp (demaid = Iwip3 demaid_*) $c if lmp==1, cluster(casename) tech(bhhh)
	set seed 339487731
	drawnorm b1-b21, n(10000) means(e(b)) cov(e(V))   clear
	gen a  =.
	gen hi =.
	gen lo =.
	gen med=.
	gen a_axis = (_n-1) in 1/81
	replace a_axis = a_axis/20 + .25 /*0.05 (log) aid increments from 0.25 to 2.25*/
	local a=.25
	while `a' <= 2.25 {
		scalar h_gdp=7.224416   		/*mean*/
		scalar h_pop=8.492726  			/*mean*/
		scalar h_d = 9					/*mean*/
		scalar h_cw =.0566038 			/*mean*/
		gen x_beta  = b1*`a'+b2*h_gdp+b3*h_pop+b4*h_cw+b5*h_d+b6*h_d^2+b7*1
		gen prob = 1-normal(x_beta)   	/*subtract from one to get the Pr(Fail) instead of Pr(MP=1|MP_t-1=1)*/
		egen hatmed=mean(prob)
		_pctile prob, p(5,95)
		gen hatlo  = r(r1)
		gen hathi = r(r2)
		quietly replace a = `a' 
		quietly replace med = hatmed if a_axis==a
		quietly replace lo =  hatlo if a_axis==a
		quietly replace hi =  hathi if a_axis==a
		drop hat* x_beta prob
		local a = `a' + 0.05
	}
	local varname "lo hi med"
	foreach x of local varname {
		replace `x' = `x'*100
	}
	drop if a_axis>2.25
	merge using temp
	label var demaid "Democracy Aid"
	graph twoway (hist demaid if demaid<=2.25 & demaid>=0.25, xscale(range(0.25 2.25)) xlabel(0.25 (0.25) 2.25) lcolor(gs12) bin(100) yaxis(2)) /*
	*/  (line hi a_axis, lpattern(dash) xscale(range(0.25 2.25)) xlabel(0.25 (0.25) 2.25) ytitle("Pr(Transition)") xtitle("Democracy Aid (log scale)")) /*
	*/  (line lo a_axis, lpattern(dash) xscale(range(0.25 2.25)) xlabel(0.25 (0.25) 2.25) ytitle("Pr(Transition)") xtitle("Democracy Aid (log scale)")) /*
	*/ (line med a_axis, lpattern(solid) legend(  order(4 "Estimate" 3 "90% CI" 1 "Aid distribution")    pos(12) col(3) ring(1)))
	* Aid = 0.75 is 25pctile: 3.6%; Aid = 1.7 is the 75pctile: 0.8%
	graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\Failure.pdf", as(pdf)  replace

* Misconduct: Bottom panel of Figure 3
	qui prep2
	global c = "lgdp lpop IMF3 first monitor"
	qui ivreg2h harass $c (demaid = Iwip3), cluster(cow) gen
	ivprobit harass $c (demaid = Iwip3 demaid_*), cluster(cow)
	sum $c if e(sample)
	pctile pct = demaid if e(sample), nq(20) genp(percent) 
	list percent pct in 1/19, clean
	drop percent pct 
	set seed 339487731
	drawnorm b1-b21, n(10000) means(e(b)) cov(e(V))   clear
	gen a  =.
	gen hi =.
	gen lo =.
	gen med=.
	gen a_axis = (_n-1) in 1/81
	replace a_axis = a_axis/20 + .2 /*0.05 (log) aid increments from 2.5 to 5*/
	local a=.2
	while `a' <= 2.1 {
		scalar h_gdp= 7.077719   	/*mean*/
		scalar h_pop=8.684992		/*mean*/
		scalar h_f = 0 				/*mode is not first election*/
		scalar h_imf =1 			/*mode, yes IMF*/
		scalar h_m =1 			/*mode, yes IMF*/
		gen x_beta  = b1*`a'+b2*h_gdp+b3*h_pop+b4*h_imf+b5*h_f+b6*h_m +b7*1
		gen prob = normal(x_beta)
		egen hatmed=mean(prob)
		_pctile prob, p(5,95)
		gen hatlo  = r(r1)
		gen hathi = r(r2)
		quietly replace a = `a' 
		quietly replace med = hatmed if a_axis==a
		quietly replace lo =  hatlo if a_axis==a
		quietly replace hi =  hathi if a_axis==a
		drop hat* x_beta prob
		local a = `a' + 0.05
	}
	local varname "lo hi med"
	foreach x of local varname {
		replace `x' = `x'*100
	}
	drop if a_axis>2.1
	set scheme lean1
	merge using temp
	label var demaid "Democracy Aid"
	 
	graph twoway (hist demaid if demaid<=2.1  & demaid>=0.2, xscale(range(0.25 2)) xlabel(0.25 (0.25) 2) lcolor(gs12) bin(100) yaxis(2)) /*
	*/ (line hi a_axis, lpattern(dash) xscale(range(0.25 2)) xlabel(0.25 (0.25) 2) ytitle("Pr(Misconduct)") xtitle("Democracy Assistance (log scale)")) /*
	*/  (line lo a_axis, lpattern(dash) xscale(range(0.25 2)) xlabel(0.25 (0.25) 2) ytitle("Pr(Misconduct)") xtitle("Democracy Assistance (log scale)")) /*
	*/ (line med a_axis, lpattern(solid) legend(  order(4 "Estimate" 3 "90% CI" 1 "Aid distribution")    pos(12) col(3) ring(1)))
		graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\Misconduct.pdf", as(pdf)  replace
	* Move from 25pctile (0.65) to 75pctile (1.6) is a move from 55% to 38% chance of electoral misconduct *
	
	
** Probit estimates for Transitions and Failures, leave-one-out graphs **  For Appendix

* Transitions *
	qui prep1
	global c = "lgdp lpop cwar dnmp dnmp2"
	set more off 
	set scheme lean1
	qui ivreg2h mp (econaid =Iinfl3) $c if lmp==0 , cluster(cow)      gen
	gen f0=.
	gen b=.
	local i=1
	local id="1 402 403 404 411 420 432 433 434 435 436 437 438 439 450 451 452 461 471 475 481 482 483 484 490 500 501 510 516 517 520 522 530 531 540 541 551 553 560 565 570 572 580 581 591 625"
	foreach c of local id {
		qui ivprobit mp (econaid =Iinfl3 econaid_*) $c if lmp==0 & cow~=`c', cluster(cow)      
		qui nlcom _b[econaid], post
		matrix beta =e(b) 
		qui replace f0 = beta[1,1] if _n==`i'
		qui replace b = beta[1,1] if `c'==1 			/*capture full sample beta; when cow==1*/
		local i = `i' +1 
	}
	local b = b  /*full sample beta*/
	gen rb = round(b, 0.001)
	local rb =rb
	twoway (hist f0, bin(50) xlabel(0 (.1) .70) xline(`b', lpattern(dash)) xtitle("Estimated Coefficients for Economic Aid") /*
	*/ legend(label(1 "Coeff. estimates excluding 1 country at a time") label(2 "Full sample coefficient is 0.49") pos(11) col(1)  ring(0))) || function x = `b',xvarlab("dash line = f(x)")  
	graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\TransitionBetas.pdf", as(pdf)  replace

* Failures *
	qui prep1
	global c = "lgdp lpop cwar dmp dmp2"
	set more off 
	set scheme lean1
	gen f0=.
	gen b=.
	qui ivreg2h mp (demaid =Iwip3) $c if lmp==1, cluster(casename)  gen    
	local i=1
	local id = "1 402 403 404 411 420 432 434 435 436 437 438 439 450 451 452 461 471 475 481 482 483 484 490 500 501 510 516 517 530 540 541 551 552 553 560 565 570 571 580 581 590 591 625"
	foreach c of local id {
		qui ivprobit mp (demaid =Iwip3 demaid_*) $c if lmp==1 & cow~=`c', cluster(casename)       
		qui nlcom _b[demaid], post
		matrix beta =e(b) 
		qui replace f0 = beta[1,1] if _n==`i'
		qui replace b = beta[1,1] if `c'==1 			/*capture full sample beta; when cow==1*/
		local i = `i' +1 
	}
	local b = b  /*full sample beta*/
	gen rb = round(b, 0.001)
	sum rb
	twoway (hist f0, bin(50) xlabel(0 (.2) 1.2) xline(`b', lpattern(dash)) xtitle("Estimated Coefficients for Democracy Aid") /*
	*/ legend(label(1 "Coeff. estimates excluding 1 country at a time") label(2 "Full sample coefficient is 0.66") pos(11) col(1)  ring(0))) || function x = `b',xvarlab("dash line = f(x)")  
	graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\FailureBetas.pdf", as(pdf)  replace
	* the outlier is mauritania: excluding this case drives up the coefficient estimate *


**************************************************************************
******* Non-proportional hazards in Transition and Failure models ********
**************************************************************************

* Transition
	qui prep1
	set scheme lean1  
	gen lnt = ln(1+dnmp)
	global c = "lgdp lpop cwar lnt"
	ivreg2 mp (econaid =Iinfl3) $c if lmp==0, cluster(cow) 
	keep if e(sample)

	stset dnmp, fail(mp)
	stcox econaid lgdp lpop cwar, nohr nolog noshow schoenfeld(sch*) scaledsch(sca*)
	estat phtest, log detail  /* nph for econaid is present */
	gen econaidXlnt = econaid*lnt
	 drop sch* sca* 
	stcox econaid lgdp lpop cwar econaidX*, nohr nolog noshow schoenfeld(sch*) scaledsch(sca*)
	estat phtest, log detail  /* nph for econaid is present */ 
	estat phtest, log plot(econaid) yline(0)
	drop sch* sca* 

	gen Iinfl3Xlnt = lnt*Iinfl3
	ivreg2h mp (econaid econaidX=Iinfl3*) $c if lmp==0, cluster(cow) first gen
	pctile pct = lnt if e(sample), nq(20) genp(percent) 
	list percent pct in 1/19, clean
	drop percent pct 
	lincom econaid + econaidX*(1.61)
	lincom econaid + econaidX*(2.40)
	lincom econaid + econaidX*(2.89)
	lincom econaid + econaidX*(3.30)
	lincom econaid + econaidX*(3.43)
	lincom econaid + econaidX*(3.47)
	lincom econaid + econaidX*(3.53)
	lincom econaid + econaidX*(3.60)
	lincom econaid + econaidX*(3.73)
	* econaid estimate ranges from 0.11 to 0.06 as log duration time declines from 10pctile to 90pctile *
	
* There is also a strong calendar time trend in the transition model, but results are robust to different ways of modelling this
	qui prep1
	set scheme lean1  
	global c = "lgdp lpop cwar dnmp*"
	ivreg2h mp (econaid =Iinfl3) $c if lmp==0, cluster(cow)  gen
	keep if e(sample)
	*Linear time trend*
	ivreg2 mp (econaid =Iinfl3 econaid_*) time $c if lmp==0, cluster(cow) ffirst orthog(Iinfl3)
	est store time1
	*Quadratic time trend*
	ivreg2 mp (econaid =Iinfl3 econaid_*) time time2 $c if lmp==0, cluster(cow) ffirst orthog(Iinfl3)
	est store time2
	*Period FE
	xi: ivreg2 mp (econaid =Iinfl3 econaid_*) yr* $c if lmp==0, cluster(cow)   ffirst orthog(Iinfl3)
	est store time3
	*Year FE
	xi: ivreg2 mp (econaid =Iinfl3 econaid_*) i.year $c if lmp==0, cluster(cow)  ffirst orthog(Iinfl3) 
	est store time4
	estout time* using AppendixB5.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(cstatp widstat N_clust N) style(tex) replace label starlevels(* 0.10 ** 0.05)


* Failure 
	qui prep1
	set scheme lean1  
	gen lnt = ln(1+dmp)
	global c = "lgdp lpop cwar lnt"
	ivreg2 mp (demaid =Iwip3) $c if lmp==1, cluster(casename) 
	keep if e(sample)
	gen fail = mp==0
	stset dmp, fail(fail)
	stcox demaid lgdp lpop cwar, nohr nolog noshow schoenfeld(sch*) scaledsch(sca*)
	estat phtest, log detail  /* NO nph for demaid is present */
 
log close
